Skip to main contentModule linalg
Source - Mat3
- cartesian_to_cylindrical
- Returns (rho, phi, z) where rho is the radial distance in the xy-plane and phi is the azimuthal angle from +x.
- cartesian_to_polar
- Returns (r, theta) where theta is the angle from +x.
- cartesian_to_spherical
- Returns (r, theta, phi) where theta is the polar angle from +z and phi is the azimuthal angle from +x.
- cylindrical_to_cartesian
- Converts cylindrical coordinates (rho, phi, z) to Cartesian (x, y, z).
- polar_to_cartesian
- Converts 2D polar coordinates (r, theta) to Cartesian (x, y).
- rotation_axis_angle
- Rodrigues’ rotation formula: rotate by
angle radians about axis.
The axis is normalized internally. - rotation_x
- Rotation matrix about the x-axis by the given angle in radians.
- rotation_y
- Rotation matrix about the y-axis by the given angle in radians.
- rotation_z
- Rotation matrix about the z-axis by the given angle in radians.
- spherical_to_cartesian
- Converts spherical coordinates (r, theta, phi) to Cartesian (x, y, z).